{% extends "base.html" %}

{% block content %}

  <h3 id="page404">Ops... Pagina non trovata!</h3>

  <p class="page404-message">
    Mi dispiace, ma non riesco a trovare la pagina che stai cercando.
  </p>

{% endblock %}
